import { Stack } from 'aws-cdk-lib';
export interface IExpressStageLegacy {
    id: string;
    stacks: Stack[];
}
/**
 * A stage that holds stacks
 */
export declare class ExpressStageLegacy implements IExpressStageLegacy {
    id: string;
    stacks: Stack[];
    constructor(id: string, stacks?: Stack[]);
    /**
     * Add a stack to the stage
     * @param stack The stack to add
     */
    addStack(stack: Stack): Stack;
}
export interface IExpressWaveLegacy {
    id: string;
    stages: IExpressStageLegacy[];
}
/**
 * A wave that holds stages
 */
export declare class ExpressWaveLegacy implements IExpressWaveLegacy {
    id: string;
    stages: IExpressStageLegacy[];
    constructor(id: string, stages?: IExpressStageLegacy[]);
    /**
     * Add a stage to the wave
     * @param id The stage identifier
     */
    addStage(id: string): ExpressStageLegacy;
}
/**
 * A CDK Express Pipeline that defines the order in which the stacks are deployed.
 *
 * This is the legacy version of the pipeline that uses the `Stack` class, for plug and play compatibility with existing CDK projects that can not
 * use the `ExpressStack` class. For new projects, use the `CdkExpressPipeline` class.
 */
export declare class CdkExpressPipelineLegacy {
    waves: IExpressWaveLegacy[];
    constructor(waves?: IExpressWaveLegacy[]);
    /** Add a wave to the pipeline
     * @param id The wave identifier
     */
    addWave(id: string): ExpressWaveLegacy;
    /** Synthesize the pipeline which creates the dependencies between the stacks in the correct order
     * @param waves The waves to synthesize
     * @param print Whether to print the order of deployment to the console
     */
    synth(waves?: IExpressWaveLegacy[], print?: boolean): void;
    /**
     * Print the order of deployment to the console
     * @param waves
     * @private
     */
    private printWaves;
}
export default CdkExpressPipelineLegacy;
